export default [
  { text: 'Overview', url: '/', type: 'inbound' },
  {
    text: 'Tutorials',
    url: 'https://learn.hashicorp.com/packer',
    type: 'outbound',
  },
  {
    text: 'Docs',
    url: '/docs',
    type: 'inbound',
  },
  {
    text: 'Plugins',
    url: '/plugins',
    type: 'inbound',
  },
  {
    text: 'Community',
    url: '/community',
    type: 'inbound',
  },
]
